aboutsummaryrefslogtreecommitdiffstats
path: root/src/MusicPipe.hxx
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2014-08-12 15:56:41 +0200
committerMax Kellermann <max@duempel.org>2014-08-12 15:56:41 +0200
commitc94b4466d52c3c625467312ea565a4685184c517 (patch)
tree940116e9613eacca9746c7f1dfa729048d34f628 /src/MusicPipe.hxx
parent61f9e79ec9921ccf5a5cd53707b8ae161c380bc4 (diff)
downloadmpd-c94b4466d52c3c625467312ea565a4685184c517.tar.gz
mpd-c94b4466d52c3c625467312ea565a4685184c517.tar.xz
mpd-c94b4466d52c3c625467312ea565a4685184c517.zip
MusicChunk: rename struct to MusicChunk
Diffstat (limited to 'src/MusicPipe.hxx')
-rw-r--r--src/MusicPipe.hxx18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/MusicPipe.hxx b/src/MusicPipe.hxx
index 3af77e60f..4f29d0728 100644
--- a/src/MusicPipe.hxx
+++ b/src/MusicPipe.hxx
@@ -29,19 +29,19 @@
#include <assert.h>
-struct music_chunk;
+struct MusicChunk;
class MusicBuffer;
/**
* A queue of #music_chunk objects. One party appends chunks at the
* tail, and the other consumes them from the head.
*/
class MusicPipe {
/** the first chunk */
- music_chunk *head;
+ MusicChunk *head;
/** a pointer to the tail of the chunk */
- music_chunk **tail_r;
+ MusicChunk **tail_r;
/** the current number of chunks */
unsigned size;
@@ -87,22 +87,22 @@ public:
* Checks if the specified chunk is enqueued in the music pipe.
*/
gcc_pure
- bool Contains(const music_chunk *chunk) const;
+ bool Contains(const MusicChunk *chunk) const;
#endif
/**
* Returns the first #music_chunk from the pipe. Returns
* nullptr if the pipe is empty.
*/
gcc_pure
- const music_chunk *Peek() const {
+ const MusicChunk *Peek() const {
return head;
}
/**
* Removes the first chunk from the head, and returns it.
*/
- music_chunk *Shift();
+ MusicChunk *Shift();
/**
* Clears the whole pipe and returns the chunks to the buffer.
@@ -114,7 +114,7 @@ public:
/**
* Pushes a chunk to the tail of the pipe.
*/
- void Push(music_chunk *chunk);
+ void Push(MusicChunk *chunk);
/**
* Returns the number of chunks currently in this pipe.
@@ -29,19 +29,19 @@
class MusicBuffer;
/**
- * A queue of #music_chunk objects. One party appends chunks at the
+ * A queue of #MusicChunk objects. One party appends chunks at the
* tail, and the other consumes them from the head.
*/
@@ -87,22 +87,22 @@ public:
#endif
/**
- * Returns the first #music_chunk from the pipe. Returns
+ * Returns the first #MusicChunk from the pipe. Returns
* nullptr if the pipe is empty.
*/